@@ -11,6 +11,9 @@ class BaseHandler(RequestHandler):
 
     """BaseHandler for all other RequestHandlers"""
 
+    __url_names__ = ["__self__"]
+    __urls__ = []
+
     @property
     def db_conn(self):
         """Returns database connection abstraction
